@@ -16,4 +16,4 @@ def passwordless_sudo(cmd="", proof="OK", **kwargs):
     args = f"sudo -n -S {cmd} 2>/dev/null".split()
     kwargs = dict(stdout=subprocess.PIPE)
     cmd = subprocess.run(args, **kwargs)
-    return (proof in str(cmd.stdout))
+    return proof in str(cmd.stdout)
